Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Scheduler ¶
type Scheduler struct {
CloudProvider cloudprovider.CloudProvider
KubeClient client.Client
Topology *Topology
}
func NewScheduler ¶
func NewScheduler(kubeClient client.Client, cloudProvider cloudprovider.CloudProvider) *Scheduler
type TopologyGroup ¶
type TopologyGroup struct {
Constraint v1.TopologySpreadConstraint
Pods []*v1.Pod
// contains filtered or unexported fields
}
TopologyGroup is a set of pods that share a topology spread constraint
func NewTopologyGroup ¶
func NewTopologyGroup(pod *v1.Pod, constraint v1.TopologySpreadConstraint) *TopologyGroup
func (*TopologyGroup) Increment ¶
func (t *TopologyGroup) Increment(domain string)
Increment increments the spread of a registered domain
func (*TopologyGroup) NextDomain ¶
func (t *TopologyGroup) NextDomain(requirement sets.String) string
NextDomain chooses a domain within the constraints that minimizes skew
func (*TopologyGroup) Register ¶
func (t *TopologyGroup) Register(domains ...string)
Click to show internal directories.
Click to hide internal directories.